/*
DynAPI 2.5x Compatibility Mode
-------------------------------------

These commands make v2.9 largely backward compatible with 2.5.  However, some changes
make it impossible to be fully compatible.  All syntax that has been changed can be
considered deprecated.  This compatibility mode is merely a starting point and it is
recommended that you read "docs/changelog.html" for a complete description of the
new features and to move your code over to 2.9 syntax.

A short list of non-compatibility:
- DynAPI.onload = function(){} can no longer be used, replace with dynapi.onLoad(function() {});
- EventListener is no longer available, it is now an empty object, and thus the e.getTarget() is
  now removed.  Instead of retreiving an object from DynEvent using e.getTarget(), you must change to
  e.getSource(), and retrieve the widget object in another fashion.

Include this file *AFTER* event.js,dyndocument.js,dynlayer.js,mouseevent.js

*/

// these have not been tested, nor is a complete list

// syntax changes
DynAPI = dynapi;
Methods = dynapi.functions;
EventListener = dynapi.functions.Null;
DynMouseEvent = MouseEvent;
dynapi.librarypath = dynapi.libraryPath = dynapi.library.path;

// v2.5x package/include system;
DynAPIObject.prototype.getLibraryPath = function() {return dynapi.library.path};
DynAPIObject.prototype.setLibraryPath = function(path) {
	dynapi.library.setPath(path);
};
DynAPIObject.prototype.addPackage = function(pckg) {
	if (!this.packages) this.packages = [];
	if (this.packages[pckg]) return;
	this.packages[pckg] = { libs: [] };
};
DynAPIObject.prototype.addLibrary = function(path,files) {
	var pckg = path.substring(0,path.indexOf('.'));
	if (!pckg) {
		alert("DynAPI Error: Incorrect DynAPI.addLibrary usage");
		return;
	}
	var name = path.substring(path.indexOf('.')+1);
	if (!this.packages[pckg]) this.addPackage(pckg);
	if (this.packages[pckg].libs[name]) {
		alert("DynAPI Error: Library "+name+" already exists");
		return;
	}
	this.packages[pckg].libs[name] = files;
};
DynAPIObject.prototype.include = function(src,pth) {
	src=src.split('.');
	if (src[src.length-1] == 'js') src.length -= 1;
	var path=pth||this.libraryPath||'';
	if (path.substr(path.length-1) != "/") path += "/";
	var pckg=src[0];
	var grp=src[1];
	var file=src[2];
	if (file=='*') {
		if (this.packages[pckg]) group=this.packages[pckg].libs[grp];
		if (group) for (var i=0;i<group.length;i++) document.write('<script language="Javascript1.2" src="'+path+pckg+'/'+grp+'/'+group[i]+'.js"><\/script>');
		else alert('include()\n\nThe following package could not be loaded:\n'+src+'\n\nmake sure you specified the correct path.');
	} else document.write('<script language="Javascript1.2" src="'+path+src.join('/')+'.js"><\/script>');
};
DynAPIObject.prototype.addLoadFunction = function(f) {
	this.onLoad(f);
};
DynAPIObject.prototype.addUnLoadFunction = function(f) {
	this.onUnload(f);
};
DynAPIObject.prototype.addResizeFunction = function(f) {
	l = {onresize : f};
	dynapi.document.addEventListener(l);
};

DynAPI.addPackage('dynapi');
DynAPI.addLibrary('dynapi.api'  ,["browser","dynlayer","dyndocument"]);
DynAPI.addLibrary('dynapi.event',["listeners","mouse","dragevent","keyboard"]);
DynAPI.addLibrary('dynapi.ext'  ,["inline","layer","dragdrop","functions"]);
DynAPI.addLibrary('dynapi.gui'  ,["viewport","dynimage","button","buttonimage","label","list","loadpanel","pushpanel","scrollbar","scrollpane","sprite"]);
DynAPI.addLibrary('dynapi.util' ,["circleanim","cookies","debug","thread","hoveranim","imganim","pathanim","console"]);

// DynLayer
DynLayer.prototype.moveTo = DynLayer.prototype.setLocation;
DynLayer.prototype.moveBy = function(x,y) {
	this.setLocation(this.x+x,this.y+y);
}
DynLayer.prototype.isDynLayer = true;
DynDocument.prototype.isDynDocument = true;

// resize events
if (dynapi.ua.ns4) {
	DynLayer.prototype.setSize = function(w,h,noevt) {
		var cw = (w!=null && w!=this.w);
		var ch = (h!=null && h!=this.h);
		if (cw) this.w = w<0? 0 : w;
		if (ch) this.h = h<0? 0 : h;
		if (cw||ch) {
			if (this._childAnchors) this._updateAnchors();
			if (this._layout) this._layout._fixLayout();
			if (this.css) {
				if (cw) this.css.clip.width = this.w;
				if (ch) this.css.clip.height = this.h;
			}
			if (noevt!=false) this.invokeEvent('resize');
		}
		return (cw||ch);
	};
}
else {
	DynLayer.prototype.setSize = function(w,h,noevt) {
		var cw = (w!=null && w!=this.w);
		var ch = (h!=null && h!=this.h);
		if (cw) this.w = w<0? 0 : w;
		if (ch) this.h = h<0? 0 : h;
		if (cw||ch) {
			if (this._childAnchors) this._updateAnchors();
			if (this._layout) this._layout._fixLayout();
			if (this.css) {
				if (cw) this.css.width = this.w||0;
				if (ch) this.css.height = this.h||0;
				if (cw || ch) this.css.clip = 'rect(0px '+(this.w||0)+'px '+(this.h||0)+'px 0px)';
			}
			if (noevt!=false) this.invokeEvent('resize');
		}
		return (cw||ch);
	};
}
DynLayer.prototype.setWidth=function(w,noevt) {this.setSize(w,null,noevt)};
DynLayer.prototype.setHeight=function(h,noevt) {this.setSize(null,h,noevt)};

DynElement._flagEvent = function(obj,type) {
	if (type=="create") {
		obj._created = true;
		obj.created = true;  // added
	}
	var l=obj.children.length;
	for (var i=0; i<l; i++) {
		DynElement._flagEvent(obj.children[i],type);
	}
	obj.invokeEvent(type);  // called after children
};